from setuptools import setup, find_packages

setup(
    name='farhoud',
    version='0.1',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
    author='Belajdel rabek ',
    author_email='belajdelmedamine@gmail.com',
    description='A package that summons farhoud '
)
